hive-vscode.effects

hive-vessel :json native payload -> VS Code effects as data. Pure.

Effects: [:show-message level message] [:upsert-panel panel-id title lines] [:close-panel panel-id] [:open-file file line column] [:send-to-terminal terminal text] [:emit-event event data] [:invalid op reason] [:unsupported op]

hive-vessel :json native payload -> VS Code effects as data. Pure.

Effects:
  [:show-message level message]
  [:upsert-panel panel-id title lines]
  [:close-panel panel-id]
  [:open-file file line column]
  [:send-to-terminal terminal text]
  [:emit-event event data]
  [:invalid op reason]
  [:unsupported op]
raw docstring

failure?clj/s

(failure? effect)

True for an effect that reports the payload could not be executed.

True for an effect that reports the payload could not be executed.
sourceraw docstring

levelsclj/s

source

payload->effectsclj/s

(payload->effects payload)

Effects for one :json native PAYLOAD (string-keyed map).

Effects for one :json native PAYLOAD (string-keyed map).
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries