ClojureScript only.

hive-vscode.ext.extension

VS Code entry point: activate wires the host and client into the editor.

VS Code entry point: activate wires the host and client into the editor.
raw docstring

activatecljs

(activate ctx)

Extension activation. Returns the public API object.

Extension activation. Returns the public API object.
sourceraw docstring

deactivatecljs

(deactivate)
source

cljdoc builds & hosts documentation for Clojure/Script libraries