hive-vscode.ext.vscode-host

IVsCodeHost over the VS Code extension API, which is injected (never required here) so the rest of the extension loads outside VS Code.

IVsCodeHost over the VS Code extension API, which is injected (never required
here) so the rest of the extension loads outside VS Code.
raw docstring

on-event!cljs

(on-event! h f)

Register (fn [event data]) for json/event deliveries. Returns a dispose fn.

Register (fn [event data]) for json/event deliveries. Returns a dispose fn.
sourceraw docstring

open-panelscljs

(open-panels h)
source

vscode-hostcljs

(vscode-host vscode)

Host over the injected VSCODE module.

Host over the injected VSCODE module.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries