Interpreter: a :json native payload -> effects -> IVsCodeHost calls -> reply. Never throws; the reply is what the extension acknowledges to hive.
Interpreter: a :json native payload -> effects -> IVsCodeHost calls -> reply. Never throws; the reply is what the extension acknowledges to hive.
(apply-payload h payload)Execute PAYLOAD on host H. Returns a reply map (schema hive-vscode.schema/Reply).
Execute PAYLOAD on host H. Returns a reply map (schema hive-vscode.schema/Reply).
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |