IVsCodeHost over the VS Code extension API, which is injected (never required here) so the rest of the extension loads outside VS Code.
IVsCodeHost over the VS Code extension API, which is injected (never required here) so the rest of the extension loads outside VS Code.
(on-event! h f)Register (fn [event data]) for json/event deliveries. Returns a dispose fn.
Register (fn [event data]) for json/event deliveries. Returns a dispose fn.
(vscode-host vscode)Host over the injected VSCODE module.
Host over the injected VSCODE module.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |